## -*- coding: utf-8 -*-
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

from cStringIO import StringIO
from Products.CMFCore.DirectoryView import addDirectoryViews
from Products.CMFCore.utils import getToolByName
from Products.PloneWeatherForecast import globalsFromInit

import string


# Configlets to be added to control panels or removed from them
configlets = (
    {
        'id'         : 'PloneWeatherForecastConfig',
        'name'       : 'Plone Weather Forecast',
        'action'     : 'string:${portal_url}/config_plone_weather_forecast',
        'condition'  : '',
        'category'   : 'Products',    # section to which the configlet should be added:
                                      # (Plone,Products,Members)
        'visible'    : 1,
        'appId'      : 'PloneWeatherForecast',
        'permission' : 'ManagePortal',
        'imageUrl'   : 'plone_weather_forecast_icon.png',
    },
)

portletPath = "here/portlet_plone_weather_forecast/macros/portlet"

def installPortlet(self, outStream) :

    if hasattr(self, "right_slots") :
        if portletPath in self.right_slots :
            outStream.write("Plone Weather Forecast portlet already installed, nothing to do.\n")
        else :
            right_slots_list = list(self.right_slots)
            self._delProperty('right_slots')
            right_slots_list.append(portletPath)
            self._setProperty('right_slots', tuple(right_slots_list), 'lines')
            outStream.write("Plone Weather Forecast was installed on the right. To change this, edit the left and right_slots properties in the ZMI.\n")
    else :
        outStream.write("No attribute right_slots was found in context, nothing done. You have to add manually '%s' in the left and right_slots properties in the ZMI.\n" % portletPath)


def uninstallPortlet(self, outStream) :

    for attributeName in ["right_slots", "left_slots"] :
        try :
            attrib = getattr(self, attributeName)
            if portletPath in attrib :
                slotsList = list(attrib)
                self._delProperty(attributeName)
                slotsList.remove(portletPath)
                self._setProperty(attributeName, tuple(slotsList), 'lines')
                outStream.write("Plone Weather Forecast was removed from %s.\n" % attributeName)
            else :
                pass
#                 outStream.write("debug : portlet not found in %s.\n" % (attributeName))
        except AttributeError :
            outStream.write("Warning : No attribute %s was found in context.\n" % attributeName)

def installSubSkin(context, skinFolder, outStream):
    """ Install a subskin in portal_skins
    """
    skinsTool = getToolByName(context, 'portal_skins')
    for skin in skinsTool.getSkinSelections() :
        path = skinsTool.getSkinPath(skin)
        path = map( string.strip, string.split( path,',' ) )
        outStream.write("path ->> %s" % path)
        if not skinFolder in path:
            try:
                path.insert( path.index( 'custom')+1, skinFolder )
            except ValueError:
                path.append(skinFolder)
            path = string.join( path, ', ' )
            skinsTool.addSkinSelection( skin, path )
            outStream.write('Subskin successfully installed into %s.\n' % skin)
        else:
            outStream.write('*** Subskin was already installed into %s.\n' % skin)

def addWeatherTool(self) :
    # Check that the tool has not been added using its id
    if not hasattr(self, 'weather_forecast_tool') :
        addTool = self.manage_addProduct['PloneWeatherForecast'].manage_addTool
        # Add the tool by its meta_type
        addTool('Plone Weather Forecast Tool')

def installConfiglet(self, out) :
    configTool = getToolByName(self, 'portal_controlpanel', None)
    if configTool:
        for conf in configlets:
            configTool.registerConfiglet(**conf)
            out.write('Added configlet %s\n' % conf['id'])

def uninstallConfiglet(self, out) :
    configTool = getToolByName(self, 'portal_controlpanel', None)
    if configTool:
        for conf in configlets:
            configTool.unregisterConfiglet(conf['id'])
            out.write('Removed configlet %s\n' % conf['id'])

def install(self) :
    outStream = StringIO()

    skinsTool = getToolByName(self, 'portal_skins')
    addDirectoryViews(skinsTool, 'skins', globalsFromInit)
    installSubSkin(self, "plone_weather_forecast", outStream)
    addWeatherTool(self)
    installPortlet(self, outStream)
    installConfiglet(self, outStream)
    return outStream.getvalue()

def uninstall(self) :
    outStream = StringIO()
    uninstallPortlet(self, outStream)
    uninstallConfiglet(self, outStream)
    return outStream.getvalue()
